#
# spec file for package libftdi1
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover -2
%define libname %{name}%{sover}

Name:           libftdi1
Version:        1.3
Release:        32.1
Summary:        Library to program and control the FTDI USB controller
License:        LGPL-2.1+ and GPL-2.0-with-classpath-exception
Group:          Hardware/Other
Url:            http://www.intra2net.com/en/developer/libftdi
Source:         http://www.intra2net.com/en/developer/libftdi/download/libftdi1-%{version}.tar.bz2
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  cmake >= 2.8
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libconfuse-devel
BuildRequires:  libusb-1_0-devel
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  python-xml
BuildRequires:  swig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Library to program and control the FTDI USB controller.
This library is used by many programs accessing FTDI USB-to-RS232 converters.

%package -n %{libname}
Summary:        Library to program and control the FTDI USB controller
Group:          System/Libraries

%description -n %{libname}
Library to program and control the FTDI USB controller.
This library is used by many programs accessing FTDI USB-to-RS232 converters.


%package binding-python
Summary:        Python binding for libftdi
Group:          Development/Languages/Python
Requires:       %{libname} = %{version}
Requires:       swig

%description binding-python
Library to program and control the FTDI USB controller.
This library is used by many programs accessing FTDI USB-to-RS232 converters.

This package provides the python binding for libftdi.

%package devel
Summary:        Header files and static libraries for libftdi
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       libusb-1_0-devel

%description devel
Header files and static libraries for libftdi.
This library is used by many programs accessing FTDI USB-to-RS232 converters.

%prep
%setup -q

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install
rm -rf %{buildroot}%{_datadir}
mkdir -p %{buildroot}%{_mandir}/man3
cd build
cp -p doc/man/man3/[^_]*.3 %{buildroot}%{_mandir}/man3
find %{buildroot} -type f -name "*.a" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc AUTHORS COPYING* LICENSE README
%{_libdir}/libftdi*.so.*

%files binding-python
%defattr(-,root,root)
%doc python/examples/*.py
%{python_sitearch}/_ftdi1.so
%{python_sitearch}/ftdi1.py

%files devel
%defattr(-,root,root)
%doc ftdi_eeprom/example.conf
%{_bindir}/libftdi*-config
%{_bindir}/ftdi_eeprom
%{_includedir}/%{name}
%{_libdir}/libftdi*.so
%{_libdir}/pkgconfig/libftdi*.pc
%{_libdir}/cmake/%{name}
%{_mandir}/man3/*%{ext_man}

%changelog
* Thu Jul  6 2017 mardnh@gmx.de
- Minor package cleanup
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Fri May 27 2016 p.drouand@gmail.com
- Update to version 1.3
  * Added ftdi_usb_get_strings2() to prevent automatic device close
  * Added ftdi_transfer_data_cancel() for cancellation of a submitted
    transfer, avoided resubmittion of a canceled transfer in the callbacks,
    replaced calls to libusb_handle_events with
    libusb_handle_events_timeout_completed
  * ftdi_eeprom / eeprom handling:
    +  Add support for arbitrary user data
    +  Add --build-eeprom support
    +  Fix use_usb_version config file option
    +  Ability to include other config files in EEPROM config file
    +  Add external oscillator enable bit
    +  Support channel configuration
    +  Added --device option to ftdi_eeprom to specify FTDI device
    +  Fixed EEPROM user-area space checks for FT232R and FT245R chips
  * Various improvements to CBUS handling, including the EEPROM
  * swig wrapper: Fix handling of binary strings in ftdi_write_data()
    for python 3
  * cbus python example code
  * ftdi_stream: fix timeout setting
  * Fixed typo in CBUS defines: CBUSG_DRIVE1 -> CBUSH_DRIVE1
- Build python binding
  * Add a libftdi1-binding-python
  * Add python-devel, python-xml and swig dependencies
- Add libconfuse-devel build dependency
* Mon Dec 15 2014 mardnh@gmx.de
- updated to 1.2
  * Support for FT230X devices (Uwe Bonnes)
  * ftdi_usb_get_strings(): Don't try to open an already open device (Denis Sirotkin)
  * Support for finding devices bricked by the Windows driver (Forest Crossman)
  * cmake build system: New LibFTDI1ConfigVersion.cmake file (xantares09)
  * Fix a typo in the MPSSE command CLK_BYTES_OR_LOW (Benjamin Vanheuverzwijn)
  * Minor fixes for MSVC++ (Andrei Errapart)
  * Various small code improvements (Florian Preinstorfer, Jochen Sprickerhof, xantares09)
- updated to 1.1
  * Fix FT232H eeprom suspend pulldown setting (Davide Michelizza)
  * Fix FT232H eeprom user area size (Davide Michelizza)
  * Improved mingw build (Paul Fertser and Michel Zou)
  * C++ wrapper: Get/set functions for USB timeouts (Jochen Sprickerhof)
  * Partial support for FT230X (Nathael Pajani)
  * New API function: ftdi_eeprom_set_strings() (Nathael Pajani)
  * Prevent possible segfault in ftdi_eeprom_decode() (Nathael Pajani)
  * Save device release number in eeprom (Jarkko Sonninen)
  * Fix "self powered" eeprom flag (Jarkko Sonninen)
  * Improved python wrapper (Michel Zou)
  * Many buildsystem improvements (Michel Zou and Mike Frysinger)
  * See the git history for more changes and fixes
- run spec-cleaner
* Wed Oct 30 2013 rw@suse.de
- updated to 1.0
  * Ported to libusb 1.x (initial work by Jie Zhang)
  * Many eeprom handling improvements (Uwe Bonnes, Anders Larsen)
  * Renamed pkconfig, library .so etc. files to "libftdi1" (Intra2net)
  * ftdi_eeprom is part of libftdi now (Intra2net)
  * New baudrate calculation code + unit tests (Uwe Bonnes and Intra2net)
  * Improved python bindings including python3 support (Michel Zou)
  * Switched completely to cmake build system (Intra2net)
  * cmake: Easy libftdi discovery via find_package() (Michel Zou)
  * eeprom handling now done via get()/set() functions (Uwe Bonnes)
  * C++ wrapper: Fixed use-after-free in List::find_all() (Intra2net)
  * Documentation updates (Xiaofan Chen)
  * See the git history for more changes and fixes
- removed buildfixes.diff
* Wed Jan  2 2013 prusnak@opensuse.org
- updated to 0.20
  * Support for FT232H (Uwe Bonnes)
  * Fixed install location of header files (Uwe Bonnes and Intra2net)
  * Backported serial_test tool from libftdi 1.x (Uwe Bonnes)
- updated to 0.19
  * Make kernel driver detach configurable (Thomas Klose)
  * Correct ftdi_poll_modem_status() result code (Tom Saunders)
  * cmake build system improvements (Evgeny Sinelnikov)
  * Fix uninitialized memory access in async mode (Intra2net)
  * Support for FT232R eeprom features (Hermann Kraus)
  * Fix size returned by ftdi_read_data (Hermann Kraus)
  * C++ wrapper: Fix infinite recursion in set_bitmode (Intra2net)
  * Improvements to the python wrapper (Flynn Marquardt and Chris Zeh)
* Thu May  3 2012 cfarrell@suse.com
- license update: LGPL-2.1+ and GPL-2.0-with-classpath-exception
  Use SPDX format (http://www.spdx.org/licenses)
* Fri Jan 21 2011 stepan@coresystems.de
- Update to 0.18
- Add COPYING.GPL and LICENSE files, too
* Mon Dec 21 2009 stepan@coresystems.de
- Update to 0.17
* Sun Oct 26 2008 jblunck@suse.de
- Initial page submission
